@@ -7,7 +7,7 @@ from fastapi.middleware.cors import CORSMiddleware
 from fastapi.staticfiles import StaticFiles
 
 from learninghouse import versions
-from learninghouse.api import api, docs
+from learninghouse.api import api, docs, ui
 from learninghouse.api.errors import (LearningHouseException,
                                       learninghouse_exception_handler,
                                       validation_error_handler)
@@ -33,6 +33,8 @@ def get_application() -> FastAPI:
     if settings.docs_url:
         application.include_router(docs.router)
 
+    application.include_router(ui.router)
+
     application.add_exception_handler(
         RequestValidationError, validation_error_handler)
     application.add_exception_handler(
@@ -87,6 +89,11 @@ def run():
         logger.info(
             f'See interactive documentation {settings.documentation_url}')
 
+    if ui.is_ui_installed():
+        logger.info(f'UI is reachable under {settings.base_url_calculated}/ui')
+    else:
+        logger.warning(f'UI is not installed under {ui.UI_DIRECTORY}')
+
     if auth.is_initial_admin_password:
         logger.warning(INITIAL_PASSWORD_WARNING)
 
